@@ -17,12 +17,12 @@ bool rcpp_constraint_budget(SEXP x,
 
   //variables
   int number_of_units = pu_data.nrows();
-  int row_constraint = op->_rhs.size();
-  int col_constraint = 0;
+  std::size_t row_constraint = op->_rhs.size();
+  std::size_t col_constraint = 0;
   int number_of_actions = dist_threats_data.nrows();
 
-  NumericVector action_costs = dist_threats_data["action_cost"];
-  NumericVector unit_costs = pu_data["monitoring_cost"];
+  std::vector<double> action_costs = dist_threats_data["action_cost"];
+  std::vector<double> unit_costs = pu_data["monitoring_cost"];
 
   for(int i = 0; i < number_of_units; i++){
     op->_A_i.push_back(row_constraint);
